aboutsummaryrefslogtreecommitdiffstats
path: root/plugins/mate/packet-mate.c
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/mate/packet-mate.c')
-rw-r--r--plugins/mate/packet-mate.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/plugins/mate/packet-mate.c b/plugins/mate/packet-mate.c
index d14dbdd45c..2334826c49 100644
--- a/plugins/mate/packet-mate.c
+++ b/plugins/mate/packet-mate.c
@@ -360,10 +360,10 @@ proto_reg_handoff_mate(void)
register_init_routine(initialize_mate);
/*
* Set the list of fields we want.
*/
set_postdissector_wanted_fields(mate_handle,
- mc->wanted_fields);
+ mc->wanted_hfids);
tap_error = register_tap_listener("frame", &mate_tap_data,
(char*) mc->tap_filter,
@@ -360,10 +360,10 @@ proto_reg_handoff_mate(void)
register_init_routine(initialize_mate);
/*
- * Set the list of fields we want.
+ * Set the list of hfids we want.
*/
set_postdissector_wanted_fields(mate_handle,